package com.caimei.controller.auth;

import com.alibaba.fastjson.JSONObject;
import com.caimei.model.ResponseJson;
import com.caimei.model.vo.ClubUserVo;
import com.caimei.model.vo.ClubVo;
import com.caimei.service.auth.AuthClubService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;

/**
 * 供应商API
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Api(tags = "机构用户API")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/club")
public class AuthClubApi {

    private final AuthClubService authClubService;


    @ApiOperation("机构列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "authUserId", required = true, value = "供应商用户id"),
            @ApiImplicitParam(name = "clubName", required = false, value = "机构名称"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/list")
    public ResponseJson<PageInfo<ClubVo>> getClubList(Integer authUserId, String clubName,
                                                      @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                      @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return authClubService.getClubList(authUserId, clubName, pageNum, pageSize);
    }


    @ApiOperation("机构用户列表")
    @GetMapping("/user/list")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "authId", required = true, value = "机构id"),
            @ApiImplicitParam(name = "mobile", required = false, value = "手机号"),
            @ApiImplicitParam(name = "name", required = false, value = "姓名"),
            @ApiImplicitParam(name = "status", required = false, value = "状态：0未绑定，1已绑定，2已过期"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    public ResponseJson<PageInfo<ClubUserVo>> getClubUserList(Integer authId, String mobile, String name, Integer status,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return authClubService.getClubUserList(authId, mobile, name, status, pageNum, pageSize);
    }

    @ApiOperation("添加/编辑机构用户")
    @PostMapping("/user/save")
    @ApiImplicitParam(name = "params", value = "clubUserId:机构用户id;authId:授权机构id;name:姓名;mobile:手机号", required = true)
    public ResponseJson saveClubUser(@RequestBody String params) {
        JSONObject paramsMap = JSONObject.parseObject(params);
        Integer clubUserId = paramsMap.getInteger("clubUserId");
        Integer authId = paramsMap.getInteger("authId");
        String name = paramsMap.getString("name");
        String mobile = paramsMap.getString("mobile");
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权机构id");
        }
        if (StringUtils.isEmpty(name)) {
            return ResponseJson.error("参数异常，请输入姓名");
        }
        if (StringUtils.isEmpty(mobile)) {
            return ResponseJson.error("参数异常，请输入手机号");
        }
        return authClubService.saveClubUser(clubUserId, authId, name, mobile);
    }

    @ApiOperation("删除机构用户")
    @PostMapping("/user/delete")
    @ApiImplicitParam(name = "params", value = "clubUserId:机构用户id", required = true)
    public ResponseJson deleteClubUser(@RequestBody String params) {
        JSONObject paramsMap = JSONObject.parseObject(params);
        Integer clubUserId = paramsMap.getInteger("clubUserId");
        if (null == clubUserId) {
            return ResponseJson.error("参数异常，机构用户id不能为空");
        }
        return authClubService.deleteClubUser(clubUserId);
    }
}
