package com.caimei.service.auth.impl;

import com.caimei.mapper.cmMapper.AddressMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.vo.AddressSelectVo;
import com.caimei.service.auth.AddressService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2022/1/6
 */
@Slf4j
@Service
public class AddressServiceImpl implements AddressService {
    @Resource
    private AddressMapper addressMapper;

    /**
     * 收货地址下拉选项列表
     *
     * @param type     选项类型：0省（默认），1市，2区
     * @param parentId 父级地址Id
     */
    @Override
    public ResponseJson<List<AddressSelectVo>> getSelectAddress(Integer type, Integer parentId) {
        if (0 == type) {
            // 获取所有省份列表
            List<AddressSelectVo> provinceList = addressMapper.getAllProvinceList();
            return ResponseJson.success(provinceList);
        } else if (1 == type) {
            // 获取当前省份下的所有城市列表
            List<AddressSelectVo> cityList = addressMapper.getCityListByProvinceId(parentId);
            return ResponseJson.success(cityList);
        } else if (2 == type) {
            // 获取当前城市下的所有地区列表
            List<AddressSelectVo> townList = addressMapper.getTownListByCityId(parentId);
            return ResponseJson.success(townList);
        }
        return ResponseJson.error("地址选项类型错误！", null);
    }

    @Override
    public ResponseJson<List<AddressSelectVo>> getAllSelectAddress() {
        // 获取所有省份列表
        List<AddressSelectVo> provinceList = addressMapper.getAllProvinceList();
        provinceList.forEach(province -> {
            // 获取当前省份下的所有城市列表
            List<AddressSelectVo> cityList = addressMapper.getCityListByProvinceId(province.getId());
            cityList.forEach(city -> {
                // 获取当前城市下的所有地区列表
                List<AddressSelectVo> townList = addressMapper.getTownListByCityId(city.getId());
                city.setChildren(townList);
            });
            province.setChildren(cityList);
        });
        return ResponseJson.success(provinceList);
    }

}
